==> snipe-it-7.0.13.zip: snipe-it-7.0.13/resources/lang/hr-HR/admin/hardware/form.php <==
<?php

return [
    'bulk_delete'		=> 'Potvrda opcije brisanja brisanja',
    'bulk_restore'      => 'Confirm Bulk Restore Assets', 
  'bulk_delete_help'	=> 'U nastavku pregledajte materijale za skupnu brisanje. Nakon što se izbrisati, ta se sredstva mogu vratiti, ali više neće biti povezana s korisnicima kojima su trenutačno dodijeljeni.',
  'bulk_restore_help'	=> 'Review the assets for bulk restoration below. Once restored, these assets will not be associated with any users they were previously assigned to.',
  'bulk_delete_warn'	=> 'Izbrisat ćete: asset_count assets.',
  'bulk_restore_warn'	=> 'You are about to restore :asset_count assets.',
    'bulk_update'		=> 'Skupna aktivacija ažuriranja',
    'bulk_update_help'	=> 'Ovaj vam obrazac omogućuje ažuriranje više imovine odjednom. Popunite polja koja su vam potrebna za promjenu. Sva polja koja su ostala prazna ostat će nepromijenjena.',
    'bulk_update_warn'	=> 'You are about to edit the properties of a single asset.|You are about to edit the properties of :asset_count assets.',
    'bulk_update_with_custom_field' => 'Note the assets are :asset_model_count different types of models.',
    'bulk_update_model_prefix' => 'On Models', 
    'bulk_update_custom_field_unique' => 'This is a unique field and can not be bulk edited.',
    'checkedout_to'		=> 'Provjereno',
    'checkout_date'		=> 'Datum kupnje',
    'checkin_date'		=> 'Datum čekanja',
    'checkout_to'		=> 'Checkout to',
    'cost'				=> 'Trošak nabave',
    'create'			=> 'Izrada alata',
    'date'				=> 'Datum kupnje',
    'depreciation'	    => 'deprecijacija',
    'depreciates_on'	=> 'Deprecira On',
    'default_location'	=> 'Zadana lokacija',
    'default_location_phone' => 'Default Location Phone',
    'eol_date'			=> 'EOL datum',
    'eol_rate'			=> 'EOL stopu',
    'expected_checkin'  => 'Očekivani datum provjere',
    'expires'			=> 'istječe',
    'fully_depreciated'	=> 'Potpuno se amortizira',
    'help_checkout'		=> 'Ako želite odmah dodijeliti ovaj materijal, odaberite "Spreman za implementaciju" iz gore navedenog popisa statusa.',
    'mac_address'		=> 'Mac adresa',
    'manufacturer'		=> 'Proizvođač',
    'model'				=> 'Model',
    'months'			=> 'mjeseci',
    'name'				=> 'Naziv imovine',
    'notes'				=> 'Bilješke',
    'order'				=> 'Broj narudžbe',
    'qr'				=> 'QR kod',
    'requestable'		=> 'Korisnici mogu zatražiti ovaj materijal',
    'redirect_to_all'   => 'Return to all :type',
    'redirect_to_type'   => 'Go to :type',
    'redirect_to_checked_out_to'   => 'Go to Checked Out to',
    'select_statustype'	=> 'Odaberite vrstu statusa',
    'serial'			=> 'Serijski',
    'status'			=> 'Status',
    'tag'				=> 'Oznaka imovine',
    'update'			=> 'Ažuriranje aktiva',
    'warranty'			=> 'garancija',
        'warranty_expires'		=> 'Jamstvo istječe',
    'years'				=> 'godina',
    'asset_location' => 'Update Asset Location',
    'asset_location_update_default_current' => 'Update default location AND actual location',
    'asset_location_update_default' => 'Update only default location',
    'asset_location_update_actual' => 'Update only actual location',
    'asset_not_deployable' => 'That asset status is not deployable. This asset cannot be checked out.',
    'asset_not_deployable_checkin' => 'That asset status is not deployable. Using this status label will checkin the asset.',
    'asset_deployable' => 'That status is deployable. This asset can be checked out.',
    'processing_spinner' => 'Processing... (This might take a bit of time on large files)',
    'optional_infos'  => 'Optional Information',
    'order_details'   => 'Order Related Information'
];

==> snipe-it-7.1.17.zip: snipe-it-7.1.17/resources/lang/hr-HR/admin/hardware/form.php <==
<?php

return [
    'bulk_delete'		=> 'Potvrda opcije brisanja brisanja',
    'bulk_restore'      => 'Confirm Bulk Restore Assets', 
  'bulk_delete_help'	=> 'U nastavku pregledajte materijale za skupnu brisanje. Nakon što se izbrisati, ta se sredstva mogu vratiti, ali više neće biti povezana s korisnicima kojima su trenutačno dodijeljeni.',
  'bulk_restore_help'	=> 'Review the assets for bulk restoration below. Once restored, these assets will not be associated with any users they were previously assigned to.',
  'bulk_delete_warn'	=> 'Izbrisat ćete: asset_count assets.',
  'bulk_restore_warn'	=> 'You are about to restore :asset_count assets.',
    'bulk_update'		=> 'Skupna aktivacija ažuriranja',
    'bulk_update_help'	=> 'Ovaj vam obrazac omogućuje ažuriranje više imovine odjednom. Popunite polja koja su vam potrebna za promjenu. Sva polja koja su ostala prazna ostat će nepromijenjena.',
    'bulk_update_warn'	=> 'You are about to edit the properties of a single asset.|You are about to edit the properties of :asset_count assets.',
    'bulk_update_with_custom_field' => 'Note the assets are :asset_model_count different types of models.',
    'bulk_update_model_prefix' => 'On Models', 
    'bulk_update_custom_field_unique' => 'This is a unique field and can not be bulk edited.',
    'checkedout_to'		=> 'Provjereno',
    'checkout_date'		=> 'Datum kupnje',
    'checkin_date'		=> 'Datum čekanja',
    'checkout_to'		=> 'Checkout to',
    'cost'				=> 'Trošak nabave',
    'create'			=> 'Izrada alata',
    'date'				=> 'Datum kupnje',
    'depreciation'	    => 'deprecijacija',
    'depreciates_on'	=> 'Deprecira On',
    'default_location'	=> 'Zadana lokacija',
    'default_location_phone' => 'Default Location Phone',
    'eol_date'			=> 'EOL datum',
    'eol_rate'			=> 'EOL stopu',
    'expected_checkin'  => 'Očekivani datum provjere',
    'expires'			=> 'istječe',
    'fully_depreciated'	=> 'Potpuno se amortizira',
    'help_checkout'		=> 'Ako želite odmah dodijeliti ovaj materijal, odaberite "Spreman za implementaciju" iz gore navedenog popisa statusa.',
    'mac_address'		=> 'Mac adresa',
    'manufacturer'		=> 'Proizvođač',
    'model'				=> 'Model',
    'months'			=> 'mjeseci',
    'name'				=> 'Naziv imovine',
    'notes'				=> 'Bilješke',
    'order'				=> 'Broj narudžbe',
    'qr'				=> 'QR kod',
    'requestable'		=> 'Korisnici mogu zatražiti ovaj materijal',
    'redirect_to_all'   => 'Return to all :type',
    'redirect_to_type'   => 'Go to :type',
    'redirect_to_checked_out_to'   => 'Go to Checked Out to',
    'select_statustype'	=> 'Odaberite vrstu statusa',
    'serial'			=> 'Serijski',
    'status'			=> 'Status',
    'tag'				=> 'Oznaka imovine',
    'update'			=> 'Ažuriranje aktiva',
    'warranty'			=> 'garancija',
        'warranty_expires'		=> 'Jamstvo istječe',
    'years'				=> 'godina',
    'asset_location' => 'Update Asset Location',
    'asset_location_update_default_current' => 'Update default location AND actual location',
    'asset_location_update_default' => 'Update only default location',
    'asset_location_update_actual' => 'Update only actual location',
    'asset_not_deployable' => 'That asset status is not deployable. This asset cannot be checked out.',
    'asset_not_deployable_checkin' => 'That asset status is not deployable. Using this status label will checkin the asset.',
    'asset_deployable' => 'That status is deployable. This asset can be checked out.',
    'processing_spinner' => 'Processing... (This might take a bit of time on large files)',
    'optional_infos'  => 'Optional Information',
    'order_details'   => 'Order Related Information',
    'calc_eol'    => 'If nulling the EOL date, use automatic EOL calculation based on the purchase date and EOL rate.',
];
